api.authentication.v1.user package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.user package

## Submodules

## api.authentication.v1.user.user_apikey module

Autogenerated API

`api.authentication.v1.user.user_apikey.` `disable_method_for_user`(userID: int, method: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Disable an authentication method for a user (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user to modify method (str) – Authentication method to enable
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 354, “limit”: 255, “responseCode”: 200, “count”: 366, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Thousand her season agree.”, “messageTemplate”: “Certain action all over floor.”, “field”: “Data drop plan paper partner safe peace.”, “parameter”: {}, “timestamp”: 790229026}], “currentPage”: 123, “size”: 197}

`api.authentication.v1.user.user_apikey.` `download_public_key`(userID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Download user public key (INTERNAL)

  Return type: | `dict`
  Parameters: | userID (int) – User ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {}

`api.authentication.v1.user.user_apikey.` `enable_method_for_user`(userID: int, method: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Enable an authentication method for a user (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user to modify method (str) – Authentication method to enable
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 837, “limit”: 802, “responseCode”: 200, “count”: 783, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Forget indicate remain management international enjoy.”, “messageTemplate”: “Allow cause many.”, “field”: “Argue fact discussion.”, “parameter”: {}, “timestamp”: 253471648}], “currentPage”: 681, “size”: 14}

`api.authentication.v1.user.user_apikey.` `get_user_methods`(userId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List authentication methods enabled for a specified user (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – User to fetch methods for
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 1000, “limit”: 391, “responseCode”: 200, “count”: 141, “data”: [{“method”: “TOTP”, “lastLoginTimestamp”: 1109825220, “lastLoginIP”: “Plant degree where statement yeah.”, “initialized”: false, “settings”: {“additionalProperties”: {}}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Treat suggest television drop fill letter.”, “messageTemplate”: “Themselves bad reduce blood between.”, “field”: “Reach talk tonight north paper offer apply.”, “parameter”: {}, “timestamp”: 1265262392}], “currentPage”: 205, “size”: 68}

`api.authentication.v1.user.user_apikey.` `initiate`(userID: int, description: str = None, validSources: <function list at 0x10b062488> = None, expirationDays: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate a new user APIkey (PUBLIC) API keys are bound to a limited IP range. The API key initialization request must specify an IP address or subnet which the API key can be used from.Attempts to use an api key from an IP outside this IP, will result in authentication error.

  To allow authentication from different IPs, issue multiple API keys.

  The initiation request returns the API key, in the format it can be used both in the Argus-API-Key header, or when initiating a durable session (/apikey/authenticate).

  The API key cannot be retrieved at a later stage. If the key is lost, it should be deletedand a new key should be issued.

  Return type: | `dict`

`api.authentication.v1.user.user_apikey.` `list`(userID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List user API keys (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 278, “limit”: 873, “responseCode”: 200, “count”: 454, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Power image until to hand financial.”, “messageTemplate”: “Guy military account difficult.”, “field”: “Return very relate me course hold.”, “parameter”: {}, “timestamp”: 670675737}], “currentPage”: 258, “size”: 821}

`api.authentication.v1.user.user_apikey.` `renew`(userID: int, keyID: int, expirationDays: int = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Renew existing user APIkey (PUBLIC) API keys have limited validity. This operationallows the administrator to renew a users API-key, to allow it to remain functional for a new validity period.

  Return type: | `dict`

`api.authentication.v1.user.user_apikey.` `reset_and_download_private_key`(userID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Reset and download user private key (INTERNAL)

  Return type: | `dict`
  Parameters: | userID (int) – User ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {}

`api.authentication.v1.user.user_apikey.` `retrieve_s_m_s_token`(userID: int, tokenSuffix: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Retrieve the SMS code sent to user (PUBLIC) SMS authentication depends on the verification code sent to the user by SMS reachingthe user. When this does not happen, this method allows an administrator to retrieve the SMS code to provide the user by phone.

  To retrieve the token, the user must provide the administrator with thesession token printed in the browser in the SMS code input screen.

  Return type: | `dict`

`api.authentication.v1.user.user_apikey.` `revoke`(userID: int, keyID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete existing user APIkey (PUBLIC)

  Return type: | `dict`
  Parameters: | userID (int) – ID of user keyID (int) – Key ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 355, “limit”: 482, “responseCode”: 200, “count”: 684, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Sell southern quality college myself actually meet.”, “messageTemplate”: “Continue stuff affect cell feel mind offer.”, “field”: “New employee knowledge voice alone both.”, “parameter”: {}, “timestamp”: 195894018}], “currentPage”: 163, “size”: 361}

`api.authentication.v1.user.user_apikey.` `setup`(userID: int, userName: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Configure user LDAP settings (INTERNAL)

  Return type: | `dict`
  Parameters: | userID (int) – User ID userName (str) – LDAP username to set for user
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 NotFoundException – on 404
  Returns: | {“offset”: 366, “limit”: 303, “responseCode”: 200, “count”: 686, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Here with many affect other learn.”, “messageTemplate”: “Decision his develop likely.”, “field”: “Toward sea wear alone public picture use.”, “parameter”: {}, “timestamp”: 275074431}], “currentPage”: 294, “size”: 198}

## Module contents